@@ -1,7 +1,7 @@
 package Release::Util::Git;
 
 our $DATE = '2017-02-09'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -60,12 +60,13 @@ sub list_git_release_tags {
         push @res, {
             tag => $tag,
             date => $epoch,
+            tz_offset => $offset,
             commit => $commit,
         },
     }
 
     if ($args{detail}) {
-        $resmeta->{'table.fields'} = [qw/tag date commit/];
+        $resmeta->{'table.fields'} = [qw/tag date tz_offset commit/];
     } else {
         @res = map { $_->{tag} } @res;
     }
@@ -88,7 +89,7 @@ Release::Util::Git - Utility routines related to software releases and git
 
 =head1 VERSION
 
-This document describes version 0.002 of Release::Util::Git (from Perl distribution Release-Util-Git), released on 2017-02-09.
+This document describes version 0.003 of Release::Util::Git (from Perl distribution Release-Util-Git), released on 2017-02-09.
 
 =head1 FUNCTIONS
 
